```
Usage: vcd network direct create [OPTIONS] <name>

Options:
  -p, --parent <external network name>
                                  Name of the external network to be connected
                                  to  [required]
  -d, --description <description>
                                  Description of the network to be created
  -s, --shared / -n, --not-shared
                                  Share/Don't share the network with other
                                  VDC(s) in the organization
  -h, --help                      Show this message and exit.

```
